@@ -12,20 +12,24 @@
 void
 prhead_page()
 {
-#if SUBLEVEL>=18	/* XXX: >=19 but for Red Hat 7.3 kerenel */
+#ifndef _page_has_zone
+	/* >= 2.4.19 and Red Hat 7.3 kerenel */
 #if CONFIG_HIGHMEM
 	mprintf(SPTR" "SPTR"    INDEX CNT "SPTR" "SPTR" FLAGS\n",
 		"ADDR", "MAPPING", "BUFFERS", "VIRTUAL");
 #else
 	mprintf(SPTR" "SPTR"    INDEX CNT "SPTR" FLAGS\n",
 		"ADDR", "MAPPING", "BUFFERS");
-#endif
+#endif /*CONFIG_HIGHMEM*/
 #else
+	/* <= 2.4.18 */
 	mprintf(SPTR" "SPTR"    INDEX CNT "SPTR" "SPTR" "SPTR" FLAGS\n",
 		"ADDR", "MAPPING", "BUFFERS", "VIRTUAL", "ZONE");
-#endif
+#endif /*!_page_has_zone*/
 }
 
+int sizeof_page = sizeof(struct page);
+
 addr_t
 print_page(addr, aflag)
 	addr_t addr;
@@ -56,12 +60,6 @@ print_page(addr, aflag)
 	return (addr_t)pg.next_hash;
 }
 
-int
-sizeof_page()
-{
-	return sizeof(struct page);
-}
-
 void
 prhead_vm_area_struct()
 {
