@@ -29,7 +29,7 @@ mprint_kobject(ko)
 void
 prhead_device()
 {
-	mprintf(SPTR" LIST "SPTR" "SPTR" "SPTR" NAME\n",
+	mprintf(SPTR" LIST "SPTR" "SPTR" "SPTR" BUS_ID\n",
 		"ADDR", "PARENT", "BUS", "DRIVER");
 }
 
@@ -51,8 +51,6 @@ print_device(addr, full)
 	mprintf(FPTR " ", dev.parent);
 	mprintf(FPTR " ", dev.bus);
 	mprintf(FPTR " ", dev.driver);
-	mprintstr(dev.name, sizeof(dev.name));
-	mprintf(" ");
 	mprintstr(dev.bus_id, sizeof(dev.bus_id));
 	mprintf("\n");
 	if (full) {
