@@ -17,24 +17,13 @@ str_usb_class(n)
 	case USB_CLASS_COMM:		return "comm";
 	case USB_CLASS_HID:		return "hid";
 	case USB_CLASS_PHYSICAL:	return "physical";
-#ifdef USB_CLASS_STILL_IMAGE
 	case USB_CLASS_STILL_IMAGE:	return "still_image";
-#endif
 	case USB_CLASS_PRINTER:		return "printer";
 	case USB_CLASS_MASS_STORAGE:	return "mass_storage";
 	case USB_CLASS_HUB:		return "hub";
-#ifdef USB_CLASS_DATA
-	case USB_CLASS_DATA:		return "data";
-#endif
-#ifdef USB_CLASS_CDC_DATA
 	case USB_CLASS_CDC_DATA:	return "cdc_data";
-#endif
-#ifdef USB_CLASS_CSCID
 	case USB_CLASS_CSCID:		return "cscid";
-#endif
-#ifdef USB_CLASS_CONTENT_SEC
 	case USB_CLASS_CONTENT_SEC:	return "content_sec";
-#endif
 	case USB_CLASS_APP_SPEC:	return "app_spec";
 	case USB_CLASS_VENDOR_SPEC:	return "vendor_spec";
 	}
@@ -45,9 +34,6 @@ PRIVATE const char *
 str_usb_type(n)
 	int n;
 {
-#ifndef USB_TYPE_MASK
-#define USB_TYPE_MASK USB_TYPE_RESERVED
-#endif
 	switch (n & USB_TYPE_MASK) {
 	case USB_TYPE_STANDARD:		return "standard";
 	case USB_TYPE_CLASS:		return "class";
@@ -87,6 +73,35 @@ str_usb_recip(n)
 	return "?";
 }
 
+PRIVATE const char *
+str_usb_device_speed(n)
+	int n;
+{
+	switch (n) {
+	case USB_SPEED_UNKNOWN:	return "Unknown";
+	case USB_SPEED_LOW:	return "Low";
+	case USB_SPEED_FULL:	return "Full";
+	case USB_SPEED_HIGH:	return "High";
+	default:		return "?";
+	}
+}
+
+PRIVATE const char *
+str_usb_device_state(n)
+	int n;
+{
+	switch (n) {
+	case USB_STATE_NOTATTACHED:	return "noattached";
+	case USB_STATE_ATTACHED:	return "attached";
+	case USB_STATE_POWERED:		return "powered";
+	case USB_STATE_DEFAULT:		return "default";
+	case USB_STATE_ADDRESS:		return "address";
+	case USB_STATE_CONFIGURED:	return "configured";
+	case USB_STATE_SUSPENDED:	return "suspended";
+	default:			return "?";
+	}
+}
+
 void
 prhead_usb_driver()
 {
@@ -116,9 +131,8 @@ S(s)
 }
 
 addr_t
-print_usb_driver(addr, list_offset, nflag)
+print_usb_driver(addr, nflag)
 	addr_t addr;
-	int list_offset;
 	int nflag;
 {
 	struct usb_driver ud;
@@ -192,37 +206,94 @@ print_usb_bus(addr, list_offset, full)
 void
 prhead_usb_device()
 {
-	mprintf(SPTR" DEV S "SPTR" P -- -- "SPTR" "SPTR" "SPTR" "SPTR"\n",
+	mprintf(SPTR" DEV S "SPTR" P -- -- "SPTR" "SPTR" "SPTR" "SPTR" C DESCRIPTOR\n",
 		"ADDR", "DEVICE", "PARENT", "BUS", "CONFIG", "HCPRIV");
 }
 
 addr_t
-print_usb_device(addr)
+print_usb_device(addr, full)
 	addr_t addr;
+	int full;
 {
 	struct usb_device ud;
 	int i;
 
 	memread(addr, sizeof(ud), &ud, "usb_device");
-	mprintf(FPTR " ", addr);
+	if (!full) {
+		mprintf(FPTR " %3x ", addr, ud.devnum);
+		mprintf("%c ",	*str_usb_device_speed(ud.speed));
+		mprintf(FPTR " %x ", ud.tt, ud.ttport);
+		mprintf("%x%x %x%x ", ud.toggle[0], ud.toggle[1],
+			ud.halted[0], ud.halted[1]);
+		mprintf(FPTR " " FPTR " " FPTR " " FPTR " ",
+			ud.parent, ud.bus, ud.config, ud.hcpriv);
+		mprintf("%x ", ud.maxchild);
+		mprintf("%s ", str_usb_desc_type(ud.descriptor.bDescriptorType));
+		mprintf("%s\n", str_usb_class(ud.descriptor.bDeviceClass));
+		return 0;
+	}
 
-	mprintf("%3x ", ud.devnum);
-	mprintf("%c ",	ud.speed==USB_SPEED_UNKNOWN? '0':
-			(ud.speed==USB_SPEED_LOW? 'L':
-			(ud.speed==USB_SPEED_FULL? 'F':
-			(ud.speed==USB_SPEED_HIGH? 'H': '?'))));
-	mprintf(FPTR " %x ", ud.tt, ud.ttport);
-	mprintf("%x%x %x%x ", ud.toggle[0], ud.toggle[1], ud.halted[0], ud.halted[1]);
-	mprintf(FPTR " " FPTR " " FPTR " " FPTR " ", ud.parent, ud.bus, ud.config, ud.hcpriv);
-#if 0
-	mprintf("%02x%02x ", ud.descriptor.bcdUSB >> 8, ud.descriptor.bcdUSB & 0xff);
-#endif
-	mprintf("%s ", str_usb_desc_type(ud.descriptor.bDescriptorType));
-	mprintf("%s\n", str_usb_class(ud.descriptor.bDeviceClass));
-	if (ud.maxchild) {
-		for (i = 0; i < USB_MAXCHILDREN && i < ud.maxchild; i++)
-			mprintf(" " FPTR, ud.children[i]);
-		mprintf("\n");
+	mprintf("addr            " FPTR "\n", addr);
+	mprintf("devnum          %x\n", ud.devnum);
+	mprintf("state           %x  %s\n", ud.state,
+		str_usb_device_state(ud.state));
+	mprintf("speed           %x  %s\n", ud.speed,
+		str_usb_device_speed(ud.speed));
+	mprintf("tt              " FPTR "\n", ud.tt);
+	mprintf("ttport          %x\n", ud.ttport);
+	mprintf("toggle          %x %x\n", ud.toggle[0], ud.toggle[1]);
+	mprintf("halted          %x %x\n", ud.halted[0], ud.halted[1]);
+	mprintf("parent          " FPTR "  (usb_device)\n", ud.parent);
+	mprintf("bus             " FPTR "  (usb_bus)\n", ud.bus);
+	mprintf("desc.bsdUSB     %04x\n", ud.descriptor.bcdUSB);
+	mprintf("desc.type       %s\n",
+		str_usb_desc_type(ud.descriptor.bDescriptorType));
+	mprintf("desc.devclass   %s\n", str_usb_class(ud.descriptor.bDeviceClass));
+	mprintf("config          " FPTR "\n", ud.config);
+	mprintf("actconfig       " FPTR "\n", ud.actconfig);
+	mprintf("langid          %x %x\n", ud.have_langid, ud.string_langid);
+	mprintf("rawdescriptors  " FPTR "\n", ud.actconfig);
+	mprintf("hcpriv          " FPTR "\n", ud.hcpriv);
+	mprintf("usbfs_dentry    " FPTR "  (dentry)\n", ud.usbfs_dentry);
+	mprintf("usbdevfs_dentry " FPTR "  (dentry)\n", ud.usbdevfs_dentry);
+	for (i = 0; i < USB_MAXCHILDREN && i < ud.maxchild; i++) {
+		mprintf("children%3x     " FPTR "  (usb_device)\n", i,
+			ud.children[i]);
 	}
 	return 0;
 }
+
+void
+prhead_usb_interface()
+{
+	mprintf(SPTR" "SPTR" ACT NUM MAX "SPTR" MIN\n",
+		"ADDR", "ALTSET", "DRIVER");
+}
+
+addr_t
+print_usb_interface(addr, full)
+	addr_t addr;
+	int full;
+{
+	struct usb_interface ui;
+
+	memread(addr, sizeof(ui), &ui, "usb_interface");
+
+	if (!full) {
+		mprintf(FPTR " ", addr);
+		mprintf(FPTR " ", ui.altsetting);
+		mprintf("%3x %3x %3x ",
+			ui.act_altsetting, ui.num_altsetting, ui.max_altsetting);
+		mprintf(FPTR " %3x\n", ui.driver, ui.minor);
+		return 0;
+	}
+
+	mprintf("addr           " FPTR "\n", addr);
+	mprintf("altsetting     " FPTR "\n", ui.altsetting);
+	mprintf("act_altsetting %x\n", ui.act_altsetting);
+	mprintf("num_altsetting %x\n", ui.num_altsetting);
+	mprintf("max_altsetting %x\n", ui.max_altsetting);
+	mprintf("driver         " FPTR "  (usb_driver)\n", ui.driver);
+	mprintf("minor          %x\n", ui.minor);
+	return 0;
+}
