@@ -311,19 +311,27 @@ mprintf(fmt, va_alist)
 }
 
 void
-mprintbit(bit, flag)
+mprintbit(bit, flags)
 	const struct bitname *bit;
-	long flag;
+	long flags;
 {
+	long decode = 0;
 	sigpiped = 0;
 
 	while (bit->value) {
-		if (bit->value & flag) {
+		if (bit->value & flags) {
+			decode |= bit->value;
 			fprintf(fp, " %s", bit->name);
 		}
 		bit++;
 	}
-	save_ad[save_cnt] = flag;
+
+	if (decode != flags)
+		fprintf(fp, " 0x%lx", flags - decode);
+	else if (flags == 0)
+		fprintf(fp, " -");
+
+	save_ad[save_cnt] = flags;
 	if (save_cnt < MAXARGS - 1)
 		save_cnt++;
 
@@ -333,18 +341,21 @@ mprintbit(bit, flag)
 	}
 }
 
-void
-mprint_str(p, maxlen)
+int
+mprintstr(p, maxlen)
 	const unsigned char *p;
 	int maxlen;
 {
+	int nc = 0;
 	sigpiped = 0;
 
 	while (--maxlen >= 0 && *p) {
 		if (*p >= ' ' && *p < 0x7f) {
 			fputc(*p, fp);
+			nc++;
 		} else {
 			fprintf(fp, "\\x%02x", *p);
+			nc += 4;
 		}
 		p++;
 	}
@@ -353,4 +364,5 @@ mprint_str(p, maxlen)
 		sigpiped = 0;
 		THROW("Broken pipe");
 	}
+	return nc;
 }
