@@ -11,7 +11,7 @@
 
 PRIVATE addr_t dump(), searchmem();
 const commandtable_t command_dump =
-	{"dump", dump, "[-h|w|d|2|4|8] address [size]", "dump virtual memory\n\t-h | -2  print by half word\n\t-w | -4  print by word\n\t-d | -8  print by double word"};
+	{"dump", dump, "[-h|w|d|2|4|8] [-n] address [size]", "dump virtual memory\n\t-h | -2  print by half word\n\t-w | -4  print by word\n\t-d | -8  print by double word\n\t-n       do not print characters"};
 const commandtable_t command_search =
 	{"search", searchmem, "address size value", "search {value} from memory between {address} and {address}+{size}"};
 
@@ -66,13 +66,14 @@ printxd(p, addr, size, mode)
 		}
 		if (i && memcmp(p, p - 16, 16) == 0) {
 			if (! astmode) {
+				astmode = 1;
 				mprintf("*\n");
 			}
-			astmode = 1;
 			continue;
 		}
+		astmode = 0;
 		mprintf("%08lx:  ", addr);
-		switch (mode) {
+		switch (mode & PRMASK) {
 		case BYBYTE:
 			mprintf("%02x%02x%02x%02x %02x%02x%02x%02x %02x%02x%02x%02x %02x%02x%02x%02x",
 				(int)p[0],	(int)p[1],	(int)p[2],
@@ -101,6 +102,10 @@ printxd(p, addr, size, mode)
 			}
 			break;
 		}
+		if (mode & PRNOCHAR) {
+			mprintf("\n");
+			continue;
+		}
 		mprintf("  %c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c\n",
 			chr2d[p[0]],	chr2d[p[1]],	chr2d[p[2]],
 			chr2d[p[3]],	chr2d[p[4]],	chr2d[p[5]],
@@ -108,7 +113,6 @@ printxd(p, addr, size, mode)
 			chr2d[p[9]],	chr2d[p[10]],	chr2d[p[11]],
 			chr2d[p[12]],	chr2d[p[13]],	chr2d[p[14]],
 			chr2d[p[15]]);
-		astmode = 0;
 	}
 
 	mprintf("%08lx: ", addr);
@@ -120,18 +124,18 @@ printxd(p, addr, size, mode)
 		memread(addr, size - i, membuf, "kernel memory");
 		p = membuf;
 	}
-	switch (mode) {
+	switch (mode & PRMASK) {
 	case BYBYTE: {
 	/*	 _+0+1+2+3 +4+5+6+7 +8+9+a+b +c+d+e+f  0123456789abcdef */
 #define	BUFORIG	"                                                      \n"
-		char	line[sizeof(BUFORIG)];
+		char	line[] = BUFORIG;
 		int	m = 1, n;
 
-		strcpy(line, BUFORIG);
 		for (n = 0; i < size; i++, n++, p++) {
 			line[m++] = int2h[*p / 16];
 			line[m++] = int2h[*p % 16];
-			line[38 + n] = chr2d[*p];
+			if (!(mode & PRNOCHAR))
+				line[38 + n] = chr2d[*p];
 			if ((i % 4) == 3)
 				m++;
 		}
@@ -172,8 +176,9 @@ dump()
 	prmode_t mode = BYBYTE;
 	addr_t addr;
 	int size = 16;
+	prmode_t nochar = 0;
 
-	while ((c = getopt(argcnt, args, "1248hwd")) != EOF) {
+	while ((c = getopt(argcnt, args, "1248hwdn")) != EOF) {
 		switch (c) {
 		case '1':
 			mode = BYBYTE; break;
@@ -186,6 +191,8 @@ dump()
 		case '8':
 		case 'd':
 			mode = BYDOUBLE; break;
+		case 'n':
+			nochar = PRNOCHAR;	break;
 		default:
 			THROW(usage);
 		}
@@ -211,7 +218,7 @@ dump()
 	if (size & ((int)mode - 1)) {
 		THROWF("invalid size (mod %d)", (int)mode);
 	}
-	printxd(NULL, addr, size, mode);
+	printxd(NULL, addr, size, mode | nochar);
 	return 0;
 }
 
@@ -223,6 +230,7 @@ dosearchmem(addr, size, val)
 {
 	addr_t i;
 	int j, cnt;
+	int found = 0;
 	addr_t membuf[65536 / sizeof(val)];
 
 	for (i = 0; i < size; i += sizeof(membuf), addr += sizeof(membuf)) {
@@ -236,9 +244,13 @@ dosearchmem(addr, size, val)
 				addr_t tmp = addr + j * sizeof(addr_t);
 				const char *p = getsymstr_func(tmp);
 				mprintf("FOUND: " FPTR "  %s\n", tmp, p? p: "-");
+				found++;
 			}
 		}
 	}
+	if (!found) {
+		mprintf("not found\n");
+	}
 }
 
 PRIVATE addr_t
