@@ -78,44 +78,49 @@ print_xfs_mount(addr, flag)
 	};
 #endif
 
-	mprintf("addr     " FPTR "  (%x)\n", addr, sizeof(m));
+	mprintf("addr         " FPTR "  (%x)\n", addr, sizeof(m));
 	memread(addr, sizeof(m), &m, "xfs_mount_t");
 
-	mprintf("ail      " FPTR " " FPTR "  (xfs_log_item)\n",
-			m.m_ail.ail_forw, m.m_ail.ail_back);
+	mprintf("ail          ");
+	if ((addr_t)m.m_ail.ail_forw == addr + OFFSET(struct xfs_mount, m_ail)
+	 && (addr_t)m.m_ail.ail_back == addr + OFFSET(struct xfs_mount, m_ail))
+		mprintf(SPTR " " SPTR, "-", "-");
+	else
+		mprintf(FPTR " " FPTR, m.m_ail.ail_forw, m.m_ail.ail_back);
+	mprintf("  (xfs_log_item)\n");
 	mprintf("ail_gen        %x\n", m.m_ail_gen);
-	mprintf("sb_bp    " FPTR "  (page_buf)\n", m.m_sb_bp);
-	mprintf("fsname   " FPTR "  \"", m.m_fsname);
+	mprintf("sb_bp        " FPTR "  (page_buf)\n", m.m_sb_bp);
+	mprintf("fsname       " FPTR "  \"", m.m_fsname);
 	memread((addr_t)m.m_fsname, sizeof(name), name, "xfs_mount.m_fsname");
-	mprint_str(name, sizeof(name));
+	mprintstr(name, sizeof(name));
 	mprintf("\"\n");
 	mprintf("bsize          %x\n", m.m_bsize);
 	mprintf("ihsize         %x\n", m.m_ihsize);
-	mprintf("ihash    " FPTR "\n", m.m_ihash);
-	mprintf("inodes   " FPTR "  (xfs_inode)\n", m.m_inodes);
+	mprintf("ihash        " FPTR "\n", m.m_ihash);
+	mprintf("inodes       " FPTR "  (xfs_inode)\n", m.m_inodes);
 	mprintf("ireclaims      %x\n", m.m_ireclaims);
 	mprintf("readio_log     %x\n", m.m_readio_log);
 	mprintf("readio_blocks  %x\n", m.m_readio_blocks);
 	mprintf("writeio_log    %x\n", m.m_writeio_log);
 	mprintf("writeio_blocks %x\n", m.m_writeio_blocks);
-	mprintf("log      " FPTR "  (xlog)\n", m.m_log);
+	mprintf("log          " FPTR "  (xlog)\n", m.m_log);
 	mprintf("logbufs        %x\n", m.m_logbufs);
 	mprintf("logbsize       %x\n", m.m_logbsize);
-	mprintf("rbmip    " FPTR "  (xfs_inode)\n", m.m_rbmip);
-	mprintf("rsumip   " FPTR "  (xfs_inode)\n", m.m_rsumip);
-	mprintf("rootip   " FPTR "  (xfs_inode)\n", m.m_rootip);
+	mprintf("rbmip        " FPTR "  (xfs_inode)\n", m.m_rbmip);
+	mprintf("rsumip       " FPTR "  (xfs_inode)\n", m.m_rsumip);
+	mprintf("rootip       " FPTR "  (xfs_inode)\n", m.m_rootip);
 #ifdef _xfs_mount_has_m_logdev_targp
 	/* new style */
 	mprintf("ddev_targp   " FPTR "\n", m.m_ddev_targp);
 	mprintf("logdev_targp " FPTR "\n", m.m_logdev_targp);
 #else
 	/* old fashion */
-	mprintf("ddev_targ   " FPTR " " FPTR " %04x\n",
+	mprintf("ddev_targ    " FPTR " " FPTR " %04x\n",
 		m.m_ddev_targ.pb_targ, m.m_ddev_targ.bd_targ, m.m_ddev_targ.dev);
-	mprintf("logdev_targ " FPTR " " FPTR " %04x\n",
+	mprintf("logdev_targ  " FPTR " " FPTR " %04x\n",
 		m.m_logdev_targ.pb_targ, m.m_logdev_targ.bd_targ, m.m_logdev_targ.dev);
 #endif
-	mprintf("flags          %x ", m.m_flags);
+	mprintf("flags          ");
 	mprintbit(mflags, m.m_flags);
 	mprintf("\n");
 
