@@ -62,7 +62,7 @@ print_pagebuf(addr, fflag)
 	mprintbit(page_buf_flags_e_bitname, pb.pb_flags);
 	mprintf("\n");
 
-	if (fflag) {
+	if (fflag & 1) {
 		mprintf("  iodone: " FPTR "\n", pb.pb_iodone);
 		mprintf("  relse:  " FPTR "\n", pb.pb_relse);
 		mprintf("  strat:  " FPTR "\n", pb.pb_strat);
@@ -98,5 +98,43 @@ print_pagebuf(addr, fflag)
 #endif
 	}
 
+#ifdef _page_buf_s_has_pb_hash_list
+	if (fflag & 2)
+		return (addr_t)pb.pb_hash_list.next;
+#endif
 	return (addr_t)pb.pb_list.next - OFFSET(page_buf_t, pb_list);
 }
+
+void
+print_all_pagebuf(addr, fflag)
+	addr_t addr;
+	int fflag;
+{
+#ifdef _page_buf_s_has_pb_hash_list
+
+#ifndef NBITS
+#define NBITS	8
+#define NHASH	(1<<NBITS)
+	typedef struct {
+		struct list_head	pb_hash;
+		int			pb_count;
+		spinlock_t		pb_hash_lock;
+	} pb_hash_t;
+#endif /*NBITS*/
+
+	pb_hash_t pbh;
+	addr_t tmp;
+	int i;
+
+	prhead_pagebuf();
+	for (i = 0; i < NHASH; i++) {
+		memread(addr + sizeof(pbh) * i, sizeof(pbh), &pbh, "pbhash");
+		if (pbh.pb_count == 0)
+			continue;
+		tmp = (addr_t)pbh.pb_hash.next;
+		while (tmp && tmp != addr + sizeof(pbh) * i + OFFSET(pb_hash_t, pb_hash)) {
+			tmp = print_pagebuf(tmp - OFFSET(page_buf_t, pb_hash_list), fflag | 2);
+		}
+	}
+#endif /*_page_buf_s_has_pb_hash_list*/
+}
