@@ -14,7 +14,7 @@
 void
 prhead_xfs_log_item()
 {
-	mprintf(SPTR"      LSN "SPTR" "SPTR" "SPTR" "SPTR" "SPTR" TYPE     FLAGS\n",
+	mprintf(SPTR"        LSN "SPTR" "SPTR" "SPTR" "SPTR" "SPTR" TYPE     FLAGS\n",
 		"ADDR", "DESC", "MOUNTP", "BIO_LIST", "CB", "OPS");
 }
 
@@ -33,7 +33,7 @@ print_xfs_log_item(addr, full)
 	memread(addr, sizeof(li), &li, "xfs_log_item_t");
 	mprintf(FPTR " ", addr);
 
-	mprintf("%8lx ", (long)li.li_lsn);
+	mprintf("%10llx ", (__s64)li.li_lsn);
 	mprintf(FPTR " " FPTR, li.li_desc, li.li_mountp);
 	mprintf(" " FPTR " " FPTR " " FPTR " ",
 		li.li_bio_list, li.li_cb, li.li_ops);
@@ -169,7 +169,7 @@ print_xfs_trans(addr)
 	mprintf("magic:        %x  ", trans.t_magic);
 	for (i = 0; i < sizeof(trans.t_magic); i++) {
 		int c = ((unsigned char *)&trans.t_magic)[i];
-		if (isascii(c) && isprint(c))
+		if (c >= 0x20 && c < 0x7f)
 			mprintf("%c", c);
 		else
 			mprintf(".");
