@@ -7,7 +7,7 @@
 
 PRIVATE addr_t xfs_mount();
 const commandtable_t command_xfs_mount =
-	{"xfs_mount", xfs_mount, "[-il] address", "[XFS] print xfs_mount_t table\n  -i  print xfs_inode table\n  -l  print xfs_log_item table"};
+	{"xfs_mount", xfs_mount, "[-i] [-l] address", "[XFS] print xfs_mount_t table\n  -i  print xfs_inode table\n  -l  print xfs_log_item table"};
 
 extern addr_t print_xfs_mount();
 
